#coding: utf-8

from django.contrib import admin
from .models import Message


class MessageAdmin(admin.ModelAdmin):
    raw_id_fields = ['to_user']
    list_filter = ['level']


admin.site.register(Message, MessageAdmin)



#coding: utf-8

import django
from django.conf import settings
from django.db import models
from django.contrib.messages.storage.base import Message as stock_message_cls


def get_user_model_fk_ref():
    ver = django.VERSION

    if ver[0] >= 1 and ver[1] >= 5:
        return settings.AUTH_USER_MODEL
    else:
        return 'auth.User'


class Message(models.Model):
    to_user = models.ForeignKey(get_user_model_fk_ref(),
        related_name='dbmessages')

    level = models.IntegerField(help_text=
        "A number. The values for the built-in levels are:"
        "<table>"
        "<tr><th>Level Constant<th>Value"
        "<tr><td>DEBUG   <td>10"
        "<tr><td>INFO    <td>20"
        "<tr><td>SUCCESS <td>25"
        "<tr><td>WARNING <td>30"
        "<tr><td>ERROR   <td>40"
        "</table>")

    message = models.TextField(default="")

    extra_tags = models.TextField(default="", blank=True, help_text=
        "Space-separated words.")

    @property
    def message_compat(self):
        return stock_message_cls(self.level, self.message, self.extra_tags)

    def __unicode__(self):
        return unicode(self.message_compat)



#coding: utf-8

import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.md')).read()

# Allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-dbmessages',
    version='0.1.0',
    packages=['dbmessages'],
    include_package_data=True,
    license='BSD License',
    description='Request-independent messaging for Django on top of contrib.messages',
    long_description=README,
    author='oDesk',
    author_email='python@odesk.com',
    maintainer='Anton Strogonoff',
    maintainer_email='anton@strogonoff.name',
    download_url='http://github.com/strogonoff/django-dbmessages',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)



#coding: utf-8

from django.contrib import messages


class DBMessageMiddleware(object):
    """
    Uses ``django.contrib.messages`` to add to the request any messages that
    authenticated user might have stored for them,
    and marks those messages as read.
    """

    def process_request(self, request):
        if not request.user.is_authenticated():
            return

        user_messages = request.user.dbmessages.all()

        if len(user_messages) < 1:
            return

        for msg in user_messages:
            messages.add_message(request, msg.level, msg.message, msg.extra_tags)

        user_messages.delete()
